"""add weather_forecast table

Revision ID: 5eee6d4b6713
Revises: 014fdfa9a966
Create Date: 2023-05-11 10:39:11.174708

"""
import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import mysql

# revision identifiers, used by Alembic.
revision = '5eee6d4b6713'
down_revision = '014fdfa9a966'
branch_labels = None
depends_on = None


def upgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table(
        'weather_forecast',
        sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
        sa.Column('date', sa.DateTime(), nullable=False),
        sa.Column(
            'sunshine_time',
            sa.Integer(),
            nullable=False,
            comment='Sunshine time is the amount of minutes with expected sunshine.',
        ),
        sa.Column(
            'low_clouds',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='0 - 4 km/ below an altitude of 640 hPa (5 km at equator). Cloud cover is expressed in percent (%).',
        ),
        sa.Column(
            'mid_clouds',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='4 - 8 km/ between an altitude of 640 and 350 hPa (10 km at equator). Cloud cover is expressed in percent (%).',
        ),
        sa.Column(
            'high_clouds',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='8 - 15 km/ between an altitude of 350 and 150 hPa (18 km at equator). Cloud cover is expressed in percent (%).',
        ),
        sa.Column(
            'total_cloud_cover',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Cloud cover is expressed in percent (%).',
        ),
        sa.Column(
            'visibility',
            sa.Integer(),
            nullable=False,
            comment='Visibility is the distance (in metres) at which an object can be clearly seen.',
        ),
        sa.Column(
            'temperature',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Air temperature is calculated for 2 meters above the ground.',
        ),
        sa.Column(
            'felt_temperature',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Felt temperature is the perceived temperature that people experience. It considers the cooling effect of wind (wind chill) as well as heating effects caused by relative humidity, radiation and low wind speeds.',
        ),
        sa.Column(
            'wind_speed',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Wind speed is the rate at which air is moving horizontally. meteoblue expresses wind speed in meter per second (m/s).',
        ),
        sa.Column(
            'wind_direction',
            sa.Integer(),
            nullable=False,
            comment='It is the direction from which the wind blows (e.g. north wind comes from the north and blows to the South corresponding to a direction of 0 degrees). It is expressed in degree (°).',
        ),
        sa.Column(
            'relative_humidity',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Relative humidity indicates how saturated the air is with moisture (expressed in percent (%)).',
        ),
        sa.Column(
            'sea_level_pressure',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='It is the atmospheric pressure at sea level. For locations which are not at sea level, the pressure is corrected to represent pressure at sea level. Sea level pressure is expressed in hectopascal (hPa).',
        ),
        sa.Column(
            'precipitation_probability',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Precipitation probability is the likelihood with which a precipitation amount of more than 0.2 mm of rain occurs within the time window of the last one, three or 24 hours, respectively.',
        ),
        sa.Column(
            'convective_precipitation',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Convective precipitation is caused by convective weather (e.g. thunderstorms). Therefore, air rises into the atmosphere, because of extreme heat. When air rises to high atmospheric levels, it cools down and consequently, vapour condenses into precipitation.',
        ),
        sa.Column(
            'is_day_light',
            mysql.DOUBLE(asdecimal=True),
            nullable=False,
            comment='Daylight duration is defined as the time between sunrise and sunset. It is dependent on the latitude and the time of the year. It is given in minutes per hour (min/h).',
        ),
        sa.Column(
            'uv_index',
            sa.Integer(),
            nullable=False,
            comment='The ultraviolet index (UV index) is an international standard measurement of the strengths of the ultraviolet radiation from the sun. The purpose is to help people to effectively protect themselves from UV light. The UV index value always refers to the highest possible value that can be achieved at midday. It is expressed in index numbers from 1 to 16.',
        ),
        sa.PrimaryKeyConstraint('id'),
    )
    # ### end Alembic commands ###


def downgrade() -> None:
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('weather_forecast')
    # ### end Alembic commands ###
